## 📊 Pipeline DAG — marketing / google_analytics

5 contracts • 3 layers

EXTERNAL
BRONZE
SILVER
GOLD
📋
google_analytics Events (Bronze)
GOOGLE_ANALYTICS
BRONZE 📄 V1.0.0 ⏱ hourly 🔒 1 PII
📋
google_analytics Sessions (Bronze)
GOOGLE_ANALYTICS
BRONZE 📄 V1.0.0 ⏱ hourly 🔒 1 PII
📋
google_analytics Sessions (Silver)
GOOGLE_ANALYTICS
SILVER 📄 V1.0.0 ⏱ hourly 🔒 1 PII
📋
google_analytics Events (Silver)
GOOGLE_ANALYTICS
SILVER 📄 V1.0.0 ⏱ hourly 🔒 1 PII
📋
Channel Performance (Gold)
GOOGLE_ANALYTICS
GOLD 📄 V1.0.0 ⏱ daily
🌐
Google Analytics API
Marketing Vendor
EXTERNAL
📋
gold_marketing_funnel
databricks • table
DOWNSTREAM
📊
Weekly GA4 Performance
power_bi • dashboard
DOWNSTREAM
🔌
Session Lookup Service
internal • api
DOWNSTREAM
◼ External ◼ Bronze ◼ Silver ◼ Gold ◼ Downstream ━━ Dependency ╌╌ Data Flow